@@ -1,10 +1,19 @@
 import datetime
+import re
+import sys
+from collections.abc import Sequence
 
 from iker.common.utils.funcutils import memorized, singleton
 
 __all__ = [
-    "iso_dt_format",
-    "iso_tm_format",
+    "basic_date_format",
+    "basic_time_format",
+    "basic_format",
+    "extended_date_format",
+    "extended_time_format",
+    "extended_format",
+    "iso_date_format",
+    "iso_time_format",
     "iso_format",
     "iso_formats",
     "dt_utc_min",
@@ -23,18 +32,13 @@ __all__ = [
 
 
 @singleton
-def iso_dt_format() -> str:
-    return "%Y-%m-%d"
-
-
-@singleton
-def iso_tm_format() -> str:
-    return "%H:%M:%S"
+def basic_date_format() -> str:
+    return "%Y%m%d"
 
 
 @memorized
-def iso_format(with_ms: bool = False, with_tz: bool = False) -> str:
-    fmt_str = "%Y-%m-%dT%H:%M:%S"
+def basic_time_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    fmt_str = "T%H%M%S"
     if with_ms:
         fmt_str = fmt_str + ".%f"
     if with_tz:
@@ -42,15 +46,57 @@ def iso_format(with_ms: bool = False, with_tz: bool = False) -> str:
     return fmt_str
 
 
+@memorized
+def basic_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    return basic_date_format() + basic_time_format(with_ms, with_tz)
+
+
+@singleton
+def extended_date_format() -> str:
+    return "%Y-%m-%d"
+
+
+@memorized
+def extended_time_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    fmt_str = "T%H:%M:%S"
+    if with_ms:
+        fmt_str = fmt_str + ".%f"
+    if with_tz:
+        fmt_str = fmt_str + "%:z"
+    return fmt_str
+
+
+@memorized
+def extended_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    return extended_date_format() + extended_time_format(with_ms, with_tz)
+
+
+iso_date_format = extended_date_format
+iso_time_format = extended_time_format
+iso_format = extended_format
+
+
 @singleton
 def iso_formats() -> list[str]:
     return [
-        iso_format(),
-        iso_format(True, False),
-        iso_format(False, True),
-        iso_format(True, True),
-        iso_dt_format(),
-        iso_tm_format(),
+        extended_format(True, False),
+        extended_format(False, True),
+        extended_format(True, True),
+        extended_format(False, False),
+        extended_date_format(),
+        extended_time_format(True, False),
+        extended_time_format(False, True),
+        extended_time_format(True, True),
+        extended_time_format(False, False),
+        basic_format(True, False),
+        basic_format(False, True),
+        basic_format(True, True),
+        basic_format(False, False),
+        basic_date_format(),
+        basic_time_format(True, False),
+        basic_time_format(False, True),
+        basic_time_format(True, True),
+        basic_time_format(False, False),
     ]
 
 
@@ -128,7 +174,11 @@ def dt_from_ts(ts: float) -> datetime.datetime:
     return datetime.datetime.fromtimestamp(ts, tz=datetime.timezone.utc)
 
 
-def dt_parse(dt_str: str, fmt_str: str | list[str] | tuple[str, ...]) -> datetime.datetime | None:
+basic_tz_regexp = re.compile(r"([+-])(\d{2})(\d{2})")
+extended_tz_regexp = re.compile(r"([+-])(\d{2}):(\d{2})")
+
+
+def dt_parse(dt_str: str, fmt_str: str | Sequence[str]) -> datetime.datetime | None:
     """
     Null safely parses given string value of a datetime to the datetime instance
 
@@ -141,11 +191,16 @@ def dt_parse(dt_str: str, fmt_str: str | list[str] | tuple[str, ...]) -> datetim
         return None
 
     if isinstance(fmt_str, str):
-        if "%z" in fmt_str or "%Z" in fmt_str:
-            return datetime.datetime.strptime(dt_str, fmt_str)
-        else:
-            return datetime.datetime.strptime(dt_str, fmt_str).replace(tzinfo=datetime.timezone.utc)
-    elif isinstance(fmt_str, (tuple, list)):
+        for tz_directive in ["%z", "%:z", "%Z"]:
+            if tz_directive in fmt_str:
+                if tz_directive == "%:z":
+                    # Replaces ISO 8601 timezone format "%:z" (e.g., "+01:00") with "%z" (e.g., "+0100")
+                    # because `datetime.strptime` does not support "%:z".
+                    dt_str = extended_tz_regexp.sub(r"\1\2\3", dt_str)
+                    fmt_str = fmt_str.replace("%:z", "%z")
+                return datetime.datetime.strptime(dt_str, fmt_str)
+        return datetime.datetime.strptime(dt_str, fmt_str).replace(tzinfo=datetime.timezone.utc)
+    elif isinstance(fmt_str, Sequence):
         for s in fmt_str:
             try:
                 return dt_parse(dt_str, s)
@@ -176,6 +231,13 @@ def dt_format(dt: datetime.datetime, fmt_str: str) -> str | None:
         year_str = str(dt.year).zfill(2)
         fmt_str = fmt_str.replace("%y", year_str)
 
+    # Manually handles the "%:z" timezone directive, since `datetime.strftime`
+    # does not support it before Python 3.12
+    if sys.version_info < (3, 12):
+        if "%:z" in fmt_str:
+            tz_str = basic_tz_regexp.sub(r"\1\2:\3", dt.strftime("%z"))
+            fmt_str = fmt_str.replace("%:z", tz_str)
+
     return dt.strftime(fmt_str)
 
 
