@@ -1,6 +1,6 @@
+import dataclasses
 import unittest
 from collections.abc import Iterable
-from dataclasses import dataclass
 from typing import Self
 
 import ddt
@@ -15,8 +15,9 @@ from iker.common.utils.sequtils import seq
 
 @ddt.ddt
 class SeqUtilsTest(unittest.TestCase):
+    data_head = [([1], 1), ([1, 2], 1)]
 
-    @ddt.data(([1], 1), ([1, 2], 1))
+    @ddt.idata(data_head)
     @ddt.unpack
     def test_head(self, data, expect):
         self.assertEqual(expect, head(data))
@@ -27,7 +28,9 @@ class SeqUtilsTest(unittest.TestCase):
     def test_head__none(self):
         self.assertRaises(Exception, head, None)
 
-    @ddt.data(([1], 1), ([1, 2], 2))
+    data_last = [([1], 1), ([1, 2], 2)]
+
+    @ddt.idata(data_last)
     @ddt.unpack
     def test_last(self, data, expect):
         self.assertEqual(expect, last(data))
@@ -38,7 +41,9 @@ class SeqUtilsTest(unittest.TestCase):
     def test_last__none(self):
         self.assertRaises(Exception, last, None)
 
-    @ddt.data(([1], []), ([1, 2], [1]), ([1, 2, 3], [1, 2]))
+    data_init = [([1], []), ([1, 2], [1]), ([1, 2, 3], [1, 2])]
+
+    @ddt.idata(data_init)
     @ddt.unpack
     def test_init(self, data, expect):
         self.assertEqual(expect, init(data))
@@ -49,7 +54,9 @@ class SeqUtilsTest(unittest.TestCase):
     def test_init__none(self):
         self.assertRaises(Exception, init, None)
 
-    @ddt.data(([1], []), ([1, 2], [2]), ([1, 2, 3], [2, 3]))
+    data_tail = [([1], []), ([1, 2], [2]), ([1, 2, 3], [2, 3])]
+
+    @ddt.idata(data_tail)
     @ddt.unpack
     def test_tail(self, data, expect):
         self.assertEqual(expect, tail(data))
@@ -60,7 +67,7 @@ class SeqUtilsTest(unittest.TestCase):
     def test_tail__none(self):
         self.assertRaises(Exception, tail, None)
 
-    @ddt.data(
+    data_grouped = [
         (None, lambda x: x, []),
         ([], lambda x: x, []),
         (
@@ -122,12 +129,14 @@ class SeqUtilsTest(unittest.TestCase):
                 (3, [[4, 4, 4], [5, 5, 5]]),
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_grouped)
     @ddt.unpack
     def test_grouped(self, data, key_func, expect):
         self.assertEqual(expect, grouped(data, key_func=key_func))
 
-    @ddt.data(
+    data_grouped__values_only = [
         (None, lambda x: x, []),
         ([], lambda x: x, []),
         (
@@ -189,12 +198,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [[4, 4, 4], [5, 5, 5]],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_grouped__values_only)
     @ddt.unpack
     def test_grouped__values_only(self, data, key_func, expect):
         self.assertEqual(expect, grouped(data, key_func=key_func, values_only=True))
 
-    @ddt.data(
+    data_deduped = [
         (None, lambda x: x, []),
         ([], lambda x, y: x == y, []),
         ([0, 0, 0, 0, 0], lambda x, y: x == y, [0]),
@@ -214,12 +225,14 @@ class SeqUtilsTest(unittest.TestCase):
             lambda x, y: abs(x - y) < 2,
             [0, 2, 4, 6, 8, 10, 12, 14, 16, 18],
         ),
-    )
+    ]
+
+    @ddt.idata(data_deduped)
     @ddt.unpack
     def test_deduped(self, data, comp_func, expect):
         self.assertEqual(expect, deduped(data, comp_func=comp_func))
 
-    @ddt.data(
+    data_batch_yield = [
         ([], 1, []),
         ([1], 1, [[1]]),
         ([1], 2, [[1]]),
@@ -228,12 +241,14 @@ class SeqUtilsTest(unittest.TestCase):
         ([1, 2, 3, 4, 5, 6], 3, [[1, 2, 3], [4, 5, 6]]),
         ([[1, 2, 3], [4, 5, 6]], 1, [[[1, 2, 3]], [[4, 5, 6]]]),
         ([[1, 2, 3], [4, 5, 6]], 2, [[[1, 2, 3], [4, 5, 6]]]),
-    )
+    ]
+
+    @ddt.idata(data_batch_yield)
     @ddt.unpack
     def test_batch_yield(self, data, batch_size, expect):
         self.assertEqual(expect, list(batch_yield(data, batch_size)))
 
-    @ddt.data(
+    data_chunk = [
         (None, lambda x: x, []),
         ([], lambda x, y: True, []),
         (
@@ -310,12 +325,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [18, 19],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_chunk)
     @ddt.unpack
     def test_chunk(self, data, chunk_func, expect):
         self.assertEqual(expect, chunk(data, chunk_func=chunk_func))
 
-    @ddt.data(
+    data_chunk__exclusive_end = [
         (None, lambda x: x, []),
         ([], lambda x, y: True, []),
         (
@@ -392,12 +409,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [18, 19],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_chunk__exclusive_end)
     @ddt.unpack
     def test_chunk__exclusive_end(self, data, chunk_func, expect):
         self.assertEqual(expect, chunk(data, chunk_func=chunk_func, exclusive_end=True))
 
-    @ddt.data(
+    data_chunk_between = [
         (None, lambda x: x, []),
         ([], lambda x, y: True, []),
         (
@@ -464,12 +483,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [18, 19],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_chunk_between)
     @ddt.unpack
     def test_chunk_between(self, data, chunk_func, expect):
         self.assertEqual(expect, chunk_between(data, chunk_func=chunk_func))
 
-    @ddt.data(
+    data_chunk_between__exclusive_end = [
         (None, lambda x: x, []),
         ([], lambda x, y: True, []),
         (
@@ -536,12 +557,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [18, 19],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_chunk_between__exclusive_end)
     @ddt.unpack
     def test_chunk_between__exclusive_end(self, data, chunk_func, expect):
         self.assertEqual(expect, chunk_between(data, chunk_func=chunk_func, exclusive_end=True))
 
-    @ddt.data(
+    data_chunk_with_key = [
         (None, lambda x: x, []),
         ([], lambda x: True, []),
         (
@@ -608,12 +631,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [18, 19],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_chunk_with_key)
     @ddt.unpack
     def test_chunk_with_key(self, data, key_func, expect):
         self.assertEqual(expect, chunk_with_key(data, key_func=key_func))
 
-    @ddt.data(
+    data_chunk_with_key__exclusive_key = [
         (None, lambda x: x, []),
         ([], lambda x: True, []),
         (
@@ -680,12 +705,14 @@ class SeqUtilsTest(unittest.TestCase):
                 [18, 19],
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_chunk_with_key__exclusive_key)
     @ddt.unpack
     def test_chunk_with_key__exclusive_key(self, data, key_func, expect):
         self.assertEqual(expect, chunk_with_key(data, key_func=key_func, exclusive_end=True))
 
-    @ddt.data(
+    data_merge_chunks = [
         (None, lambda x: x, []),
         ([], lambda x, y: True, []),
         (
@@ -734,12 +761,14 @@ class SeqUtilsTest(unittest.TestCase):
             lambda x, y: last(x) % 10 == 4,
             [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
         ),
-    )
+    ]
+
+    @ddt.idata(data_merge_chunks)
     @ddt.unpack
     def test_merge_chunks(self, data, merge_func, expect):
         self.assertEqual(expect, merge_chunks(data, merge_func=merge_func))
 
-    @ddt.data(
+    data_merge_chunks__drop_exclusive_end = [
         (None, lambda x: x, []),
         ([], lambda x, y: True, []),
         (
@@ -788,13 +817,15 @@ class SeqUtilsTest(unittest.TestCase):
             lambda x, y: last(init(x)) % 10 == 4,
             [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
         ),
-    )
+    ]
+
+    @ddt.idata(data_merge_chunks__drop_exclusive_end)
     @ddt.unpack
     def test_merge_chunks__drop_exclusive_end(self, data, merge_func, expect):
         self.assertEqual(expect, merge_chunks(data, merge_func=merge_func, drop_exclusive_end=True))
 
 
-@dataclass(frozen=True, eq=True, order=True)
+@dataclasses.dataclass(frozen=True, eq=True, order=True)
 class Naming(object):
     serial: int
     name: str
@@ -816,8 +847,7 @@ class NamingSeq(Seq[Naming]):
 
 @ddt.ddt
 class SeqTest(unittest.TestCase):
-
-    @ddt.data(
+    data_builtin_init = [
         ([], []),
         (seq([]), []),
         (seq(seq([])), []),
@@ -830,7 +860,9 @@ class SeqTest(unittest.TestCase):
         (range(1, 6), [1, 2, 3, 4, 5]),
         (seq(range(1, 6)), [1, 2, 3, 4, 5]),
         (seq(seq(range(1, 6))), [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_builtin_init)
     @ddt.unpack
     def test_builtin_init(self, data, expect):
         self.assertEqual(seq(data).data, expect)
@@ -839,18 +871,20 @@ class SeqTest(unittest.TestCase):
         with self.assertRaises(ValueError):
             seq(object())
 
-    @ddt.data(
+    data_builtin_add = [
         ([], [], []),
         ([0], [], [0]),
         ([], [0], [0]),
         ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5], [1, 2, 3, 4, 5, 1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_builtin_add)
     @ddt.unpack
     def test_builtin_add(self, a, b, expect):
         actual = seq(a) + seq(b)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_builtin_getitem = [
         ([0], 0, [0]),
         ([1, 2, 3, 4, 5], 0, [1]),
         ([1, 2, 3, 4, 5], -1, [5]),
@@ -860,7 +894,9 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], slice(-1, None), [5]),
         ([1, 2, 3, 4, 5], slice(1, -1), [2, 3, 4]),
         ([1, 2, 3, 4, 5], slice(1, -1, 2), [2, 4]),
-    )
+    ]
+
+    @ddt.idata(data_builtin_getitem)
     @ddt.unpack
     def test_builtin_getitem(self, data, item, expect):
         actual = seq(data)[item]
@@ -870,50 +906,58 @@ class SeqTest(unittest.TestCase):
         with self.assertRaises(ValueError):
             seq([])[object()]
 
-    @ddt.data(
+    data_builtin_len = [
         ([], 0),
         ([0], 1),
         ([1, 2, 3, 4, 5], 5),
-    )
+    ]
+
+    @ddt.idata(data_builtin_len)
     @ddt.unpack
     def test_builtin_len(self, data, expect):
         actual = len(seq(data))
         self.assertEqual(actual, expect)
 
-    @ddt.data(
+    data_builtin_contains = [
         ([], 0, False),
         ([0], 0, True),
         ([0], -1, False),
         ([1, 2, 3, 4, 5], 0, False),
         ([1, 2, 3, 4, 5], 1, True),
         ([1, 2, 3, 4, 5], -1, False),
-    )
+    ]
+
+    @ddt.idata(data_builtin_contains)
     @ddt.unpack
     def test_builtin_contains(self, data, item, expect):
         actual = item in seq(data)
         self.assertEqual(actual, expect)
 
-    @ddt.data(
+    data_builtin_iter = [
         ([], []),
         ([0], [0]),
         ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_builtin_iter)
     @ddt.unpack
     def test_builtin_iter(self, data, expect):
         actual = list(x for x in seq(data))
         self.assertEqual(actual, expect)
 
-    @ddt.data(
+    data_builtin_reversed = [
         ([], []),
         ([0], [0]),
         ([1, 2, 3, 4, 5], [5, 4, 3, 2, 1]),
-    )
+    ]
+
+    @ddt.idata(data_builtin_reversed)
     @ddt.unpack
     def test_builtin_reversed(self, data, expect):
         actual = list(x for x in reversed(seq(data)))
         self.assertEqual(actual, expect)
 
-    @ddt.data(
+    data_count = [
         ([], 0, 0),
         ([0], 0, 1),
         ([0], -1, 0),
@@ -922,13 +966,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 0, 0),
         ([1, 2, 3, 4, 5], 1, 1),
         ([1, 2, 3, 4, 5], -1, 0),
-    )
+    ]
+
+    @ddt.idata(data_count)
     @ddt.unpack
     def test_count(self, data, item, expect):
         actual = seq(data).count(item)
         self.assertEqual(actual, expect)
 
-    @ddt.data(
+    data_count_if = [
         ([], lambda x: True, 0),
         ([0], lambda x: True, 1),
         ([0], lambda x: False, 0),
@@ -942,13 +988,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], lambda x: x % 2 == 1, 3),
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 0, 6),
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 1, 9),
-    )
+    ]
+
+    @ddt.idata(data_count_if)
     @ddt.unpack
     def test_count_if(self, data, func, expect):
         actual = seq(data).count_if(func)
         self.assertEqual(actual, expect)
 
-    @ddt.data(
+    data_take_left = [
         ([], 0, []),
         ([], 1, []),
         ([0], 0, []),
@@ -958,13 +1006,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 1, [1]),
         ([1, 2, 3, 4, 5], 5, [1, 2, 3, 4, 5]),
         ([1, 2, 3, 4, 5], 6, [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_take_left)
     @ddt.unpack
     def test_take_left(self, data, n, expect):
         actual = seq(data).take_left(n)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_take_right = [
         ([], 0, []),
         ([], 1, []),
         ([0], 0, []),
@@ -974,174 +1024,204 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 1, [5]),
         ([1, 2, 3, 4, 5], 5, [1, 2, 3, 4, 5]),
         ([1, 2, 3, 4, 5], 6, [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_take_right)
     @ddt.unpack
     def test_take_right(self, data, n, expect):
         actual = seq(data).take_right(n)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_reverse = [
         ([], []),
         ([0], [0]),
         ([0, 0, 0], [0, 0, 0]),
         ([1, 2, 3, 4, 5], [5, 4, 3, 2, 1]),
-    )
+    ]
+
+    @ddt.idata(data_reverse)
     @ddt.unpack
     def test_reverse(self, data, expect):
         actual = seq(data).reverse()
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_distinct = [
         ([], []),
         ([0], [0]),
         ([0, 0, 0], [0]),
         ([1, 2, 3, 4, 5], [1, 2, 3, 4, 5]),
         ([1, 2, 3, 4, 5, 1, 2, 3, 4, 1, 2, 3, 1, 2, 1], [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_distinct)
     @ddt.unpack
     def test_distinct(self, data, expect):
         actual = seq(data).distinct()
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_scan_left = [
         ([], 0, lambda x, y: x, []),
         ([], None, lambda x, y: x, []),
         ([0], 1, lambda x, y: x + y, [1]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [2, 4, 7, 11, 16]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [1, 2, 6, 24, 120]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [1, 12, 123, 1234, 12345]),
-    )
+    ]
+
+    @ddt.idata(data_scan_left)
     @ddt.unpack
     def test_scan_left(self, data, zero, func, expect):
         actual = seq(data).scan_left(zero, func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_scan_right = [
         ([], 0, lambda x, y: x, []),
         ([], None, lambda x, y: x, []),
         ([0], 1, lambda x, y: x + y, [1]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16, 15, 13, 10, 6]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120, 120, 60, 20, 5]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [54321, 5432, 543, 54, 5]),
-    )
+    ]
+
+    @ddt.idata(data_scan_right)
     @ddt.unpack
     def test_scan_right(self, data, zero, func, expect):
         actual = seq(data).scan_right(zero, func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_map = [
         ([], lambda x: x, []),
         ([0], lambda x: x, [0]),
         ([1, 2, 3, 4, 5], lambda x: x * 2, [2, 4, 6, 8, 10]),
         ([1, 2, 3, 4, 5], lambda x: x ** 2, [1, 4, 9, 16, 25]),
-    )
+    ]
+
+    @ddt.idata(data_map)
     @ddt.unpack
     def test_map(self, data, func, expect):
         actual = seq(data).map(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_fold_left = [
         ([], 0, lambda x, y: x, [0]),
         ([], None, lambda x, y: x, []),
         ([0], 1, lambda x, y: x + y, [1]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [12345]),
-    )
+    ]
+
+    @ddt.idata(data_fold_left)
     @ddt.unpack
     def test_fold_left(self, data, zero, func, expect):
         actual = seq(data).fold_left(zero, func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_fold_right = [
         ([], 0, lambda x, y: x, [0]),
         ([0], 1, lambda x, y: x + y, [1]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [54321]),
-    )
+    ]
+
+    @ddt.idata(data_fold_right)
     @ddt.unpack
     def test_fold_right(self, data, zero, func, expect):
         actual = seq(data).fold_right(zero, func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_reduce = [
         ([], lambda x, y: x, []),
         ([0], lambda x, y: x + y, [0]),
         ([1, 2, 3, 4, 5], lambda x, y: x + y, [15]),
         ([1, 2, 3, 4, 5], lambda x, y: y, [5]),
-    )
+    ]
+
+    @ddt.idata(data_reduce)
     @ddt.unpack
     def test_reduce(self, data, func, expect):
         actual = seq(data).reduce(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_max = [
         ([], None, []),
         ([0], None, [0]),
         ([1, 2, 3, 4, 5], None, [5]),
         ([1, 2, 3, 4, 5], lambda x, y: True, [1]),
         ([1, 2, 3, 4, 5], lambda x, y: False, [5]),
-    )
+    ]
+
+    @ddt.idata(data_max)
     @ddt.unpack
     def test_max(self, data, func, expect):
         actual = seq(data).max(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_min = [
         ([], None, []),
         ([0], None, [0]),
         ([1, 2, 3, 4, 5], None, [1]),
         ([1, 2, 3, 4, 5], lambda x, y: True, [1]),
         ([1, 2, 3, 4, 5], lambda x, y: False, [5]),
-    )
+    ]
+
+    @ddt.idata(data_min)
     @ddt.unpack
     def test_min(self, data, func, expect):
         actual = seq(data).min(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_group = [
         ([], lambda x: x % 2, []),
         ([0], lambda x: x % 2, [(0, [0])]),
         ([1, 2, 3, 4, 5], lambda x: x % 2, [(0, [2, 4]), (1, [1, 3, 5])]),
         ([1, 2, 3, 4, 5], lambda x: x * 2, [(2, [1]), (4, [2]), (6, [3]), (8, [4]), (10, [5])]),
-    )
+    ]
+
+    @ddt.idata(data_group)
     @ddt.unpack
     def test_group(self, data, func, expect):
         actual = seq(data).group(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_keys = [
         ([], []),
         ([(0, "")], [0]),
         ([(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e")], [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_keys)
     @ddt.unpack
     def test_keys(self, data, expect):
         actual = seq(data).keys()
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_values = [
         ([], []),
         ([(0, "")], [""]),
         ([(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e")], ["a", "b", "c", "d", "e"]),
-    )
+    ]
+
+    @ddt.idata(data_values)
     @ddt.unpack
     def test_values(self, data, expect):
         actual = seq(data).values()
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_swap = [
         ([], []),
         ([(0, "")], [("", 0)]),
         ([(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e")], [("a", 1), ("b", 2), ("c", 3), ("d", 4), ("e", 5)]),
-    )
+    ]
+
+    @ddt.idata(data_swap)
     @ddt.unpack
     def test_swap(self, data, expect):
         actual = seq(data).swap()
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_map_keys = [
         ([], lambda x: x, []),
         ([(0, "0")], lambda x: x * 2, [(0, "0")]),
         ([(0, "0")], str, [("0", "0")]),
@@ -1155,13 +1235,15 @@ class SeqTest(unittest.TestCase):
             str,
             [("1", "1"), ("2", "2"), ("3", "3"), ("4", "4"), ("5", "5")],
         ),
-    )
+    ]
+
+    @ddt.idata(data_map_keys)
     @ddt.unpack
     def test_map_keys(self, data, func, expect):
         actual = seq(data).map_keys(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_map_values = [
         ([], lambda x: x, []),
         ([(0, "0")], lambda x: x * 2, [(0, "00")]),
         ([(0, "0")], int, [(0, 0)]),
@@ -1175,13 +1257,15 @@ class SeqTest(unittest.TestCase):
             int,
             [(1, 1), (2, 2), (3, 3), (4, 4), (5, 5)],
         ),
-    )
+    ]
+
+    @ddt.idata(data_map_values)
     @ddt.unpack
     def test_map_values(self, data, func, expect):
         actual = seq(data).map_values(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_flat_map = [
         ([], lambda x: x, []),
         ([[]], lambda x: x, []),
         ([[0]], lambda x: x, [0]),
@@ -1189,37 +1273,43 @@ class SeqTest(unittest.TestCase):
         ([[], [1], [2], [3], [4], [5], []], lambda x: x, [1, 2, 3, 4, 5]),
         ([[], [1, 2, 3, 4, 5], []], lambda x: x, [1, 2, 3, 4, 5]),
         ([1, 2, 3, 4, 5], lambda x: list(range(x)), [0, 0, 1, 0, 1, 2, 0, 1, 2, 3, 0, 1, 2, 3, 4]),
-    )
+    ]
+
+    @ddt.idata(data_flat_map)
     @ddt.unpack
     def test_flat_map(self, data, func, expect):
         actual = seq(data).flat_map(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_flatten = [
         ([], []),
         ([[]], []),
         ([[0]], [0]),
         ([[1, 2, 3, 4, 5]], [1, 2, 3, 4, 5]),
         ([[], [1], [2], [3], [4], [5], []], [1, 2, 3, 4, 5]),
         ([[], [1, 2, 3, 4, 5], []], [1, 2, 3, 4, 5]),
-    )
+    ]
+
+    @ddt.idata(data_flatten)
     @ddt.unpack
     def test_flatten(self, data, expect):
         actual = seq(data).flatten()
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_group_map = [
         ([], lambda x: x % 2, lambda x: x ** 2, []),
         ([0], lambda x: x % 2, lambda x: x ** 2, [(0, [0])]),
         ([1, 2, 3, 4, 5], lambda x: x % 2, lambda x: x ** 2, [(0, [4, 16]), (1, [1, 9, 25])]),
         ([1, 2, 3, 4, 5], lambda x: x, lambda x: x ** 2, [(1, [1]), (2, [4]), (3, [9]), (4, [16]), (5, [25])]),
-    )
+    ]
+
+    @ddt.idata(data_group_map)
     @ddt.unpack
     def test_group_map(self, data, group_func, map_func, expect):
         actual = seq(data).group_map(group_func, map_func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_filter = [
         ([], lambda x: True, []),
         ([0], lambda x: True, [0]),
         ([0], lambda x: False, []),
@@ -1233,13 +1323,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], lambda x: x % 2 == 1, [1, 3, 5]),
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 0, [2, 2, 4, 4, 4, 4]),
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 1, [1, 3, 3, 3, 5, 5, 5, 5, 5]),
-    )
+    ]
+
+    @ddt.idata(data_filter)
     @ddt.unpack
     def test_filter(self, data, func, expect):
         actual = seq(data).filter(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_filter_not = [
         ([], lambda x: True, []),
         ([0], lambda x: True, []),
         ([0], lambda x: False, [0]),
@@ -1253,13 +1345,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], lambda x: x % 2 == 1, [2, 4]),
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 0, [1, 3, 3, 3, 5, 5, 5, 5, 5]),
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x % 2 == 1, [2, 2, 4, 4, 4, 4]),
-    )
+    ]
+
+    @ddt.idata(data_filter_not)
     @ddt.unpack
     def test_filter_not(self, data, func, expect):
         actual = seq(data).filter_not(func)
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_sort = [
         ([], lambda x: x, []),
         ([0], lambda x: x, [0]),
         ([0, 0, 0], lambda x: x, [0, 0, 0]),
@@ -1268,13 +1362,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5], lambda x: x, [1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5]),
         ([1, 2, 3, 4, 5, 2, 3, 4, 5, 3, 4, 5, 4, 5, 5], lambda x: x, [1, 2, 2, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5]),
         ([1, 2, 3, 4, 5, 2, 3, 4, 5, 3, 4, 5, 4, 5, 5], lambda x: -x, [5, 5, 5, 5, 5, 4, 4, 4, 4, 3, 3, 3, 2, 2, 1]),
-    )
+    ]
+
+    @ddt.idata(data_sort)
     @ddt.unpack
     def test_sort(self, data, func, expect):
         actual = (seq(data).sort(func))
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_zip = [
         ([], [], []),
         ([0], [], []),
         ([], [0], []),
@@ -1285,13 +1381,15 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], [5, 4, 3, 2, 1], [(1, 5), (2, 4), (3, 3), (4, 2), (5, 1)]),
         ([1, 2, 3, 4, 5], ["a", "b", "c", "d", "e"], [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e")]),
         (["a", "b", "c", "d", "e"], [1, 2, 3, 4, 5], [("a", 1), ("b", 2), ("c", 3), ("d", 4), ("e", 5)]),
-    )
+    ]
+
+    @ddt.idata(data_zip)
     @ddt.unpack
     def test_zip(self, a, b, expect):
         actual = seq(a).zip(seq(b))
         self.assertEqual(actual.data, expect)
 
-    @ddt.data(
+    data_zip_fill = [
         ([], [], 0, []),
         ([0], [], None, [(0, None)]),
         ([0], [], 1, [(0, 1)]),
@@ -1334,7 +1432,9 @@ class SeqTest(unittest.TestCase):
             0,
             [(1, "a"), (2, "b"), (3, "c"), (4, "d"), (5, "e"), (6, 0), (7, 0)],
         ),
-    )
+    ]
+
+    @ddt.idata(data_zip_fill)
     @ddt.unpack
     def test_zip_fill(self, a, b, fill, expect):
         actual = seq(a).zip_fill(seq(b), fill)
