@@ -13,30 +13,33 @@ from iker.common.utils.strutils import trim_to_empty, trim_to_none
 
 @ddt.ddt
 class StrUtilsTest(unittest.TestCase):
-
-    @ddt.data(
+    data_is_none = [
         (None, True),
         ("", False),
         (" ", False),
         ("\t", False),
         ("dummy", False),
-    )
+    ]
+
+    @ddt.idata(data_is_none)
     @ddt.unpack
     def test_is_none(self, data, expect):
         self.assertEqual(expect, is_none(data))
 
-    @ddt.data(
+    data_is_empty = [
         (None, True),
         ("", True),
         (" ", False),
         ("\t", False),
         ("dummy", False),
-    )
+    ]
+
+    @ddt.idata(data_is_empty)
     @ddt.unpack
     def test_is_empty(self, data, expect):
         self.assertEqual(expect, is_empty(data))
 
-    @ddt.data(
+    data_is_blank = [
         (None, True),
         ("", True),
         (" ", True),
@@ -44,12 +47,14 @@ class StrUtilsTest(unittest.TestCase):
         ("\t", True),
         ("\n", True),
         ("dummy", False),
-    )
+    ]
+
+    @ddt.idata(data_is_blank)
     @ddt.unpack
     def test_is_blank(self, data, expect):
         self.assertEqual(expect, is_blank(data))
 
-    @ddt.data(
+    data_trim_to_none = [
         (None, None, None),
         ("", None, None),
         (" ", None, None),
@@ -59,12 +64,14 @@ class StrUtilsTest(unittest.TestCase):
         ("dummy! ", None, "dummy!"),
         (" dummy!", "!", " dummy"),
         ("dummy! ", "!", "dummy! "),
-    )
+    ]
+
+    @ddt.idata(data_trim_to_none)
     @ddt.unpack
     def test_trim_to_none(self, data, chars, expect):
         self.assertEqual(expect, trim_to_none(data, chars))
 
-    @ddt.data(
+    data_trim_to_empty = [
         (None, None, ""),
         ("", None, ""),
         (" ", None, ""),
@@ -74,12 +81,14 @@ class StrUtilsTest(unittest.TestCase):
         ("dummy! ", None, "dummy!"),
         (" dummy!", "!", " dummy"),
         ("dummy! ", "!", "dummy! "),
-    )
+    ]
+
+    @ddt.idata(data_trim_to_empty)
     @ddt.unpack
     def test_trim_to_empty(self, data, chars, expect):
         self.assertEqual(expect, trim_to_empty(data, chars))
 
-    @ddt.data(
+    data_parse_bool = [
         (None, False),
         (0, False),
         (1, True),
@@ -114,12 +123,14 @@ class StrUtilsTest(unittest.TestCase):
         ("N", False),
         (True, True),
         (False, False),
-    )
+    ]
+
+    @ddt.idata(data_parse_bool)
     @ddt.unpack
     def test_parse_bool(self, data, expect):
         self.assertEqual(expect, parse_bool(data))
 
-    @ddt.data(
+    data_parse_int_or = [
         (False, 0),
         (True, 1),
         (0, 0),
@@ -140,12 +151,14 @@ class StrUtilsTest(unittest.TestCase):
         ("0o70", 0o70),
         ("0b11", 0b11),
         ("0b10", 0b10),
-    )
+    ]
+
+    @ddt.idata(data_parse_int_or)
     @ddt.unpack
     def test_parse_int_or(self, data, expect):
         self.assertEqual(expect, parse_int_or(data))
 
-    @ddt.data(
+    data_parse_float_or = [
         (False, 0.0),
         (True, 1.0),
         (0, 0.0),
@@ -166,12 +179,14 @@ class StrUtilsTest(unittest.TestCase):
         ("0.0e0", 0.0),
         ("+1.0e+0", 1.0),
         ("-1.0e-0", -1.0),
-    )
+    ]
+
+    @ddt.idata(data_parse_float_or)
     @ddt.unpack
     def test_parse_float_or(self, data, expect):
         self.assertEqual(expect, parse_float_or(data))
 
-    @ddt.data(
+    data_str_conv = [
         (1, 1),
         (0, 0),
         (-1, -1),
@@ -196,12 +211,14 @@ class StrUtilsTest(unittest.TestCase):
         ("1970-01-01T00:00:00", dt_utc(1970, 1, 1, 0, 0, 0)),
         ("2020-12-31T23:59:59", dt_utc(2020, 12, 31, 23, 59, 59)),
         ("dummy", "dummy"),
-    )
+    ]
+
+    @ddt.idata(data_str_conv)
     @ddt.unpack
     def test_str_conv(self, data, expect):
         self.assertEqual(expect, str_conv(data))
 
-    @ddt.data(
+    data_parse_params_string = [
         ("", {}),
         (" \t", {}),
         (",-,", {}),
@@ -234,13 +251,15 @@ class StrUtilsTest(unittest.TestCase):
                 "dummy_key_2": "dummy_value_2_key=dummy_value_2_value",
             },
         ),
-    )
+    ]
+
+    @ddt.idata(data_parse_params_string)
     @ddt.unpack
     def test_parse_params_string(self, data, expect):
         self.assertDictEqual(expect, parse_params_string(data))
         self.assertDictEqual(expect, parse_params_string(make_params_string(parse_params_string(data))))
 
-    @ddt.data(
+    data_make_params_string = [
         (None, ""),
         ({}, ""),
         ({"foo": "bar"}, "foo=bar"),
@@ -267,13 +286,15 @@ class StrUtilsTest(unittest.TestCase):
             },
             "dummy_key_1=dummy_value_1_key=dummy_value_1_value,dummy_key_2=dummy_value_2_key=dummy_value_2_value",
         ),
-    )
+    ]
+
+    @ddt.idata(data_make_params_string)
     @ddt.unpack
     def test_make_params_string(self, data, expect):
         self.assertEqual(expect, make_params_string(data))
         self.assertEqual(expect, make_params_string(parse_params_string(make_params_string(data))))
 
-    @ddt.data(
+    data_strip_margin = [
         (
             """""",
             [
@@ -460,7 +481,9 @@ class StrUtilsTest(unittest.TestCase):
             ],
             ""
         ),
-    )
+    ]
+
+    @ddt.idata(data_strip_margin)
     @ddt.unpack
     def test_strip_margin(self, data, expect, line_concat: str = " "):
         self.assertEqual(strip_margin(data, line_concat=line_concat), "\n".join(expect))
